@@ -3,25 +3,16 @@ getContrasts <- function(model, set = NULL,
                          scaleRef = "mean",
                          scaleWeights = NULL,
                          dispersion = NULL,
-                         use.eliminate = TRUE,
                          ...){
     coefs <- parameters(model)
     l <- length(coefs)
+    if (!l)
+        stop("Model has no non-eliminated parameters")
     of.interest <- ofInterest(model)
-    if (is.null(of.interest)) {
-        if (l == model$eliminate) stop("Model has no parameters of interest")
-        of.interest <- (model$eliminate + 1):l
-    }
+    if (!length(of.interest)) of.interest <- seq(l)
     coefNames <- names(coefs)
-    if (is.null(set)) {
-        of.interest <- ofInterest(model)
-        if (is.null(of.interest)) {
-            if (l == model$eliminate)
-                stop("Model has no parameters of interest")
-            of.interest <- (model$eliminate + 1):l
-        }
+    if (is.null(set))
         set <- unlist(relimp::pickFrom(coefNames[of.interest], 1, ...))
-    }
     setLength <- length(set)
     if (setLength == 0) stop(
             "No non-empty parameter set specified")
@@ -53,7 +44,7 @@ getContrasts <- function(model, set = NULL,
                           stop("Specified ", refName, " is not an opton.")))
     }
 
-    setCoefs <- coefs[names(coefs) %in% set]
+    setCoefs <- coefs[coefNames %in% set]
     contr <- setCoefs - ref %*% setCoefs
     grad <- diag(rep(1, setLength))
     grad <- grad - ref
@@ -81,8 +72,7 @@ getContrasts <- function(model, set = NULL,
     combMatrix[match(set, coefNames), ] <- grad
     colnames(combMatrix) <- set
 
-    Vcov <-  vcov(model, dispersion = dispersion,
-                  use.eliminate = use.eliminate)
+    Vcov <-  vcov(model, dispersion = dispersion)
 
     iden <- checkEstimable(model, combMatrix)
     if (any(!na.omit(iden))) {
