@@ -1,5 +1,5 @@
 profile.gnm <- function (fitted, which = ofInterest(fitted), alpha = 0.05,
-                         maxsteps = 10, stepsize = NULL, trace = FALSE, ...) 
+                         maxsteps = 10, stepsize = NULL, trace = FALSE, ...)
 {
     fittedCoef <- parameters(fitted)
     coefNames <- names(fittedCoef)
@@ -8,7 +8,7 @@ profile.gnm <- function (fitted, which = ofInterest(fitted), alpha = 0.05,
         which <- 1:p
     else if (is.numeric(which))
         which <- which
-    else if (is.character(which)) 
+    else if (is.character(which))
         which <- match(which, coefNames)
     summ <- summary(fitted)
     sterr <- summ$coefficients[, "Std. Error"]
@@ -38,7 +38,7 @@ profile.gnm <- function (fitted, which = ofInterest(fitted), alpha = 0.05,
             ## estimate quadratic in the region MLE +/- zmax*se
             margin <- zmax * sterr[i]
             updatedDev <- numeric(2)
-            for (sgn in c(-1, 1)) { 
+            for (sgn in c(-1, 1)) {
                 val <- fittedCoef[i] + sgn * margin
                 updated <-
                     suppressWarnings(update(fitted, constrain =
@@ -67,9 +67,9 @@ profile.gnm <- function (fitted, which = ofInterest(fitted), alpha = 0.05,
                         (2 * quad)
                     firstApprox <- par.vals[maxsteps + 1 + sgn * sub, i]
                     ## if likelihood approx quadratic use default stepsize, else
-                    if (sgn * (root - firstApprox) > stepsize[dir]) {
+                    if (sgn * (root - firstApprox) > 0) {
                         ## not gone out far enough, check for asymptote
-                        val <- fittedCoef[i] + sgn * 1000
+                        val <- fittedCoef[i] + sgn * 10 * sterr[i]
                         updated <-
                             suppressWarnings(update(fitted, constrain =
                                                     c(fittedConstrain, i),
@@ -80,9 +80,11 @@ profile.gnm <- function (fitted, which = ofInterest(fitted), alpha = 0.05,
                                                     start = fittedCoef))
                         if (!is.null(updated) &&
                             sqrt((deviance(updated) - fittedDev)/disp) < zmax)
-                            asymptote[dir] <- TRUE   
+                            asymptote[dir] <- TRUE
                     }
-                    if (abs(root - firstApprox) > stepsize[dir] &&
+                    ## if root more than one step away from firstApprox, i.e.
+                    ## less than two steps away from fittedCoef, halve stepsize
+                    if (abs(sgn * (firstApprox - root)) > stepsize[dir] &&
                         !asymptote[dir]) {
                         prof[[par]][maxsteps + 1 + sgn * sub] <- 0
                         par.vals[maxsteps + 1 + sgn * sub, ] <- NA
@@ -92,7 +94,7 @@ profile.gnm <- function (fitted, which = ofInterest(fitted), alpha = 0.05,
             }
         }
         for (sgn in c(-1, 1)) {
-            if (trace) 
+            if (trace)
                 prattle("\nParameter:", par, c("down", "up")[(sgn + 1)/2 + 1],
                         "\n")
             step <- 0
@@ -117,7 +119,7 @@ profile.gnm <- function (fitted, which = ofInterest(fitted), alpha = 0.05,
                 }
                 init <- parameters(updated)
                 zz <- (deviance(updated) - fittedDev)/disp
-                if (zz > -0.001) 
+                if (zz > -0.001)
                   zz <- max(zz, 0)
                 else stop("profiling has found a better solution, ",
                           "so original fit had not converged")
